import _extends from "@babel/runtime/helpers/esm/extends";
import _objectWithoutPropertiesLoose from "@babel/runtime/helpers/esm/objectWithoutPropertiesLoose";
var _excluded = ["apiKey", "center", "children", "errorNode", "isInteractive", "height", "width", "language", "loaderNode", "staticImageNode", "zoom", "onError", "onLoad", "onUnmount"];
import { useCallback } from 'react';
import PropTypes from 'prop-types';
import { GoogleMap as DynamicMap, useLoadScript } from '@react-google-maps/api';
import AtomSkeleton from '@s-ui/react-atom-skeleton';
import useControlledState from '@s-ui/react-hooks/lib/useControlledState/index.js';
import MapGoogleCircle from './circle/index.js';
import StaticMap from './image/index.js';
import MapGoogleMarker from './marker/index.js';
import MapGooglePolygon from './polygon/index.js';
import MapGooglePolyline from './polyline/index.js';
import MapGoogleRectangle from './rectangle/index.js';
import { BASE_CLASS, CONTAINER_CLASSNAME, DEFAULT_CENTER, DEFAULT_LANGUAGE, DEFAULT_ZOOM, getDefaultMapSize, handle } from './config.js';
import { jsx as _jsx } from "react/jsx-runtime";

function MapGoogle(_ref) {
  var apiKey = _ref.apiKey,
      _ref$center = _ref.center,
      center = _ref$center === void 0 ? DEFAULT_CENTER : _ref$center,
      children = _ref.children,
      errorNode = _ref.errorNode,
      isInteractiveProp = _ref.isInteractive,
      height = _ref.height,
      width = _ref.width,
      _ref$language = _ref.language,
      language = _ref$language === void 0 ? DEFAULT_LANGUAGE : _ref$language,
      loaderNode = _ref.loaderNode,
      staticImageNode = _ref.staticImageNode,
      _ref$zoom = _ref.zoom,
      zoom = _ref$zoom === void 0 ? DEFAULT_ZOOM : _ref$zoom,
      onError = _ref.onError,
      onLoad = _ref.onLoad,
      onUnmount = _ref.onUnmount,
      others = _objectWithoutPropertiesLoose(_ref, _excluded);

  var _useControlledState = useControlledState(isInteractiveProp),
      isInteractive = _useControlledState[0],
      setIsInteractive = _useControlledState[1];

  var _useLoadScript = useLoadScript({
    googleMapsApiKey: apiKey,
    language: language
  }),
      isLoaded = _useLoadScript.isLoaded,
      loadError = _useLoadScript.loadError;

  var handleOnLoad = useCallback(function (mapInstance) {
    handle(onLoad)(mapInstance);
  }, [onLoad]);
  var handleClick = useCallback(function () {
    setIsInteractive(true);
  }, [setIsInteractive]);

  if (loadError) {
    return errorNode ? /*#__PURE__*/_jsx("div", {
      className: BASE_CLASS,
      children: errorNode
    }) : null;
  }

  var MapElement = isInteractive ? DynamicMap : StaticMap;
  var mapSize = getDefaultMapSize({
    height: height,
    width: width
  });
  return /*#__PURE__*/_jsx("div", {
    className: BASE_CLASS,
    onClick: handleClick,
    children: isLoaded ? /*#__PURE__*/_jsx("div", {
      style: mapSize,
      children: /*#__PURE__*/_jsx(MapElement, _extends({
        apiKey: apiKey,
        center: center,
        height: height,
        isInteractive: isInteractive,
        mapContainerClassName: CONTAINER_CLASSNAME,
        onError: onError,
        onLoad: handleOnLoad,
        onUnmount: onUnmount,
        width: width,
        zoom: zoom
      }, others, {
        children: isInteractive ? children : staticImageNode
      }))
    }) : loaderNode || /*#__PURE__*/_jsx(AtomSkeleton, _extends({}, mapSize))
  });
}

MapGoogle.displayName = 'MapGoogle';
export default MapGoogle;
export { MapGoogleCircle, MapGoogleMarker, MapGoogleRectangle, StaticMap as MapGoogleImage, MapGooglePolygon, MapGooglePolyline };